@@ -4,16 +4,21 @@
 #include <numbers.h>
 #include <complex.h>
 
-gnm_float lgamma1p (gnm_float a);
 gnm_float stirlerr(gnm_float n);
 
 gnm_float gnm_gamma (gnm_float x);
+gnm_float gnm_gammax (gnm_float x, int *expb);
 gnm_float gnm_fact (gnm_float x);
-int       qfactf (gnm_float x, GnmQuad *mant, int *exp2);
-void complex_gamma (gnm_complex *dst, gnm_complex const *src);
-void complex_fact (gnm_complex *dst, gnm_complex const *src);
-void complex_igamma (gnm_complex *dst, gnm_complex const  *a, gnm_complex const *z,
-		     gboolean lower, gboolean regularized);
+gnm_float gnm_factx (gnm_float x, int *expb);
+int       qfactf (gnm_float x, GnmQuad *mant, int *expb);
+gnm_complex gnm_complex_gamma (gnm_complex z, int *expb);
+gnm_complex gnm_complex_fact (gnm_complex z, int *expb);
+gnm_complex gnm_complex_igamma (gnm_complex a, gnm_complex z,
+				gboolean lower, gboolean regularized);
+
+gnm_float gnm_fact2 (int x);
+
+gnm_float gnm_digamma (gnm_float x);
 
 gnm_float gnm_lbeta (gnm_float a, gnm_float b);
 gnm_float gnm_beta (gnm_float a, gnm_float b);
